@@ -25,7 +25,6 @@
  * =======================================================================
  */
 
-#include "../../client/refresh/header/local.h"
 #include "../../client/header/keyboard.h"
 #include "../generic/header/input.h"
 #include "../../client/header/client.h"
@@ -83,6 +82,9 @@ cvar_t *m_yaw;
 cvar_t *sensitivity;
 static cvar_t *windowed_mouse;
 
+
+extern void GLimp_GrabInput(qboolean grab);
+
 /* ------------------------------------------------------------------ */
 
 /*
@@ -294,6 +296,8 @@ IN_TranslateSDLtoQ2Key(unsigned int keysym)
 
 /* ------------------------------------------------------------------ */
 
+extern int glimp_refreshRate;
+
 /*
  * Updates the input queue state. Called every
  * frame by the client and does nearly all the
@@ -428,6 +432,12 @@ IN_Update(void)
 				{
 					Key_MarkAllUp();
 				}
+				else if(event.window.event == SDL_WINDOWEVENT_MOVED)
+				{
+					// make sure GLimp_GetRefreshRate() will query from SDL again - the window might
+					// be on another display now!
+					glimp_refreshRate = -1;
+				}
 
 #else /* SDL1.2 */
 			case SDL_ACTIVEEVENT:
@@ -454,6 +464,22 @@ IN_Update(void)
 	 */
 	GLimp_GrabInput(want_grab);
 }
+
+/*
+ * Removes all pending events from SDLs queue.
+ */
+void
+In_FlushQueue(void)
+{
+#if SDL_VERSION_ATLEAST(2, 0, 0)
+	SDL_FlushEvents(SDL_FIRSTEVENT, SDL_LASTEVENT);
+#else
+	SDL_Event event;
+	while(SDL_PollEvent(&event));
+#endif
+
+	Key_MarkAllUp();
+}
  
 /*
  * Move handling
