@@ -537,6 +537,10 @@ CL_InitLocal(void)
 	gender_auto = Cvar_Get("gender_auto", "1", CVAR_ARCHIVE);
 	gender->modified = false;
 
+	// USERINFO cvars are special, they just need to be registered
+	Cvar_Get("password", "", CVAR_USERINFO);
+	Cvar_Get("spectator", "0", CVAR_USERINFO);
+
 	cl_vwep = Cvar_Get("cl_vwep", "1", CVAR_ARCHIVE);
 
 	/* register our commands */
@@ -707,8 +711,8 @@ CL_UpdateWindowedMouse(void)
 	}
 }
 
-qboolean GLimp_VsyncEnabled(void);
 int GLimp_GetRefreshRate(void);
+qboolean R_IsVSyncActive(void);
 
 void
 CL_Frame(int msec)
@@ -732,7 +736,7 @@ CL_Frame(int msec)
 	}
 
 	// Target render frame rate
-	if (GLimp_VsyncEnabled())
+	if (R_IsVSyncActive())
 	{
 		rfps = GLimp_GetRefreshRate();
 
@@ -826,7 +830,7 @@ CL_Frame(int msec)
 			double frametime = (1000.0 / cl_maxfps->value - packetdelta) <= (1000.0 / gl_maxfps->value - renderdelta) ?
 							   (1000.0 / cl_maxfps->value - packetdelta) : (1000.0 / gl_maxfps->value - renderdelta);
 
-			if (frametime > 1)
+			if (frametime > 1) // FIXME: why > ??
 			{
 				Sys_Sleep(1);
 			}
@@ -987,8 +991,6 @@ CL_Init(void)
 
 	CL_InitLocal();
 
-	FS_ExecAutoexec();
-
 	Cbuf_Execute();
 
 	Key_ReadConsoleHistory();
