@@ -745,7 +745,7 @@ FS_LoadPAK(const char *packPath)
 	pack->numFiles = numFiles;
 	pack->files = files;
 
-	Com_Printf("Added packfile '%s' (%i files).\n", pack, numFiles);
+	Com_Printf("Added packfile '%s' (%i files).\n", pack->name, numFiles);
 
 	return pack;
 }
@@ -816,7 +816,7 @@ FS_LoadPK3(const char *packPath)
 	pack->numFiles = numFiles;
 	pack->files = files;
 
-	Com_Printf("Added packfile '%s' (%i files).\n", pack, numFiles);
+	Com_Printf("Added packfile '%s' (%i files).\n", pack->name, numFiles);
 
 	return pack;
 }
@@ -942,6 +942,11 @@ FS_AddHomeAsGameDirectory(char *dir)
 	char gdir[MAX_OSPATH];
 	size_t len;
 
+	if (portable->value)
+	{
+		return;
+	}
+
 	home = Sys_GetHomeDir();
 
 	if (home == NULL)
@@ -1068,33 +1073,6 @@ FS_Path_f(void)
 #endif
 }
 
-void
-FS_ExecAutoexec(void)
-{
-	char *dir;
-	char name[MAX_QPATH];
-
-	dir = (char *)Cvar_VariableString("gamedir");
-
-	if (dir[0] != '\0')
-	{
-		Com_sprintf(name, sizeof(name), "%s/%s/autoexec.cfg",
-				fs_basedir->string, dir);
-	}
-	else
-	{
-		Com_sprintf(name, sizeof(name), "%s/%s/autoexec.cfg",
-				fs_basedir->string, BASEDIRNAME);
-	}
-
-	if (Sys_FindFirst(name, 0, SFF_SUBDIR | SFF_HIDDEN | SFF_SYSTEM) != NULL)
-	{
-		Cbuf_AddText("exec autoexec.cfg\n");
-	}
-
-	Sys_FindClose();
-}
-
 /*
  * Sets the gamedir and path to a different directory.
  */
@@ -1110,6 +1088,13 @@ FS_SetGamedir(char *dir)
 		return;
 	}
 
+    /* Do not set BASEDIR as gamedir. It was already set by FS_InitFilesystem()
+     * and setting it again f*cks the search pathes up. Yes, this a hack. */
+	if(!Q_stricmp(dir, BASEDIRNAME))
+	{
+		return;
+	}
+
 	/* Free up any current game dir info. */
 	while (fs_searchPaths != fs_baseSearchPaths)
 	{
@@ -1554,6 +1539,8 @@ FS_Dir_f(void)
 void
 FS_InitFilesystem(void)
 {
+	char scrnshotdir[MAX_OSPATH];
+
 	/* Register FS commands. */
 	Cmd_AddCommand("path", FS_Path_f);
 	Cmd_AddCommand("link", FS_Link_f);
@@ -1604,6 +1591,12 @@ FS_InitFilesystem(void)
 	/* Create directory if it does not exist. */
 	FS_CreatePath(fs_gamedir);
 
+	/* create the scrnshots directory if it doesn't exist
+	 * (do it here instead of in ref_gl so ref_gl doesn't need mkdir)
+	 */
+	Com_sprintf(scrnshotdir, sizeof(scrnshotdir), "%s/scrnshot", FS_Gamedir());
+	Sys_Mkdir(scrnshotdir);
+
 	Com_Printf("Using '%s' for writing.\n", fs_gamedir);
 }
 
