@@ -32,8 +32,7 @@
 #include "shared.h"
 #include "crc.h"
 
-/* Should have 4 characters. */
-#define YQ2VERSION "6.00"
+#define YQ2VERSION "7.01"
 #define BASEDIRNAME "baseq2"
 
 #ifndef YQ2OSTYPE
@@ -684,7 +683,6 @@ void FS_InitFilesystem(void);
 void FS_SetGamedir(char *dir);
 char *FS_Gamedir(void);
 char *FS_NextPath(char *prevpath);
-void FS_ExecAutoexec(void);
 int FS_LoadFile(char *path, void **buffer);
 
 /* a null buffer will just return the file length without loading */
@@ -710,8 +708,9 @@ void FS_CreatePath(char *path);
 
 void Com_BeginRedirect(int target, char *buffer, int buffersize, void (*flush));
 void Com_EndRedirect(void);
-void Com_Printf(char *fmt, ...);
-void Com_DPrintf(char *fmt, ...);
+void Com_Printf(char *fmt, ...) __attribute__ ((format (printf, 1, 2)));
+void Com_DPrintf(char *fmt, ...) __attribute__ ((format (printf, 1, 2)));
+void Com_VPrintf(int print_level, const char *fmt, va_list argptr); /* print_level is PRINT_ALL or PRINT_DEVELOPER */
 void Com_MDPrintf(char *fmt, ...);
 void Com_Error(int code, char *fmt, ...);
 void Com_Quit(void);
@@ -727,6 +726,7 @@ extern cvar_t *modder;
 extern cvar_t *dedicated;
 extern cvar_t *host_speeds;
 extern cvar_t *log_stats;
+extern cvar_t *portable;
 
 extern FILE *log_stats_file;
 
@@ -769,6 +769,7 @@ void Sys_Sleep(int msec);
 void Sys_FreeLibrary(void *handle);
 void *Sys_LoadLibrary(const char *path, const char *sym, void **handle);
 void *Sys_GetProcAddress(void *handle, const char *sym);
+void Sys_RedirectStdout(void);
 
 /* CLIENT / SERVER SYSTEMS */
 
