@@ -224,7 +224,11 @@ ai_charge(edict_t *self, float dist)
 		return;
 	}
 
-	VectorSubtract(self->enemy->s.origin, self->s.origin, v);
+	if(self->enemy)
+	{
+		VectorSubtract(self->enemy->s.origin, self->s.origin, v);
+	}
+
 	self->ideal_yaw = vectoyaw(v);
 	M_ChangeYaw(self);
 
@@ -411,7 +415,11 @@ HuntTarget(edict_t *self)
 		self->monsterinfo.run(self);
 	}
 
-	VectorSubtract(self->enemy->s.origin, self->s.origin, vec);
+	if(visible(self, self->enemy))
+	{
+		VectorSubtract(self->enemy->s.origin, self->s.origin, vec);
+	}
+
 	self->ideal_yaw = vectoyaw(vec);
 
 	/* wait a while before first attack */
@@ -424,7 +432,7 @@ HuntTarget(edict_t *self)
 void
 FoundTarget(edict_t *self)
 {
-	if (!self)
+	if (!self|| !self->enemy || !self->enemy->inuse)
 	{
 		return;
 	}
@@ -437,7 +445,7 @@ FoundTarget(edict_t *self)
 		level.sight_entity->light_level = 128;
 	}
 
-	self->show_hostile = level.time + 1; /* wake up other monsters */
+	self->show_hostile = (int)level.time + 1; /* wake up other monsters */
 
 	VectorCopy(self->enemy->s.origin, self->monsterinfo.last_sighting);
 	self->monsterinfo.trail_time = level.time;
@@ -616,7 +624,7 @@ FindTarget(edict_t *self)
 
 		if (r == RANGE_NEAR)
 		{
-			if ((client->show_hostile < level.time) && !infront(self, client))
+			if ((client->show_hostile < (int)level.time) && !infront(self, client))
 			{
 				return false;
 			}
@@ -733,7 +741,7 @@ M_CheckAttack(edict_t *self)
 	float chance;
 	trace_t tr;
 
-	if (!self)
+	if (!self || !self->enemy || !self->enemy->inuse)
 	{
 		return false;
 	}
@@ -936,8 +944,10 @@ ai_checkattack(edict_t *self)
 	vec3_t temp;
 	qboolean hesDeadJim;
 
-	if (!self)
+	if (!self || !self->enemy || !self->enemy->inuse)
 	{
+		enemy_vis = false;
+
 		return false;
 	}
 
@@ -950,9 +960,9 @@ ai_checkattack(edict_t *self)
 			return false;
 		}
 
-		if (self->monsterinfo.aiflags & AI_SOUND_TARGET)
+		if ((self->monsterinfo.aiflags & AI_SOUND_TARGET) && !visible(self, self->goalentity))
 		{
-			if ((level.time - self->enemy->teleport_time) > 5.0)
+			if ((level.time - self->enemy->last_sound_time) > 5.0)
 			{
 				if (self->goalentity == self->enemy)
 				{
@@ -971,12 +981,12 @@ ai_checkattack(edict_t *self)
 				if (self->monsterinfo.aiflags & AI_TEMP_STAND_GROUND)
 				{
 					self->monsterinfo.aiflags &=
-						~(AI_STAND_GROUND | AI_TEMP_STAND_GROUND);
+							~(AI_STAND_GROUND | AI_TEMP_STAND_GROUND);
 				}
 			}
 			else
 			{
-				self->show_hostile = level.time + 1;
+				self->show_hostile = (int)level.time + 1;
 				return false;
 			}
 		}
@@ -1049,7 +1059,7 @@ ai_checkattack(edict_t *self)
 	}
 
 	/* wake up other monsters */
-	self->show_hostile = level.time + 1;
+	self->show_hostile = (int)level.time + 1;
 
 	/* check knowledge of enemy */
 	enemy_vis = visible(self, self->enemy);
@@ -1069,10 +1079,13 @@ ai_checkattack(edict_t *self)
 		}
 	}
 
-	enemy_infront = infront(self, self->enemy);
-	enemy_range = range(self, self->enemy);
-	VectorSubtract(self->enemy->s.origin, self->s.origin, temp);
-	enemy_yaw = vectoyaw(temp);
+	if (self->enemy)
+	{
+		enemy_infront = infront(self, self->enemy);
+		enemy_range = range(self, self->enemy);
+		VectorSubtract(self->enemy->s.origin, self->s.origin, temp);
+		enemy_yaw = vectoyaw(temp);
+	}
 
 	if (self->monsterinfo.attack_state == AS_MISSILE)
 	{
@@ -1114,7 +1127,7 @@ ai_run(edict_t *self, float dist)
 	float left, center, right;
 	vec3_t left_target, right_target;
 
-	if (!self)
+	if (!self || !self->enemy || !self->enemy->inuse)
 	{
 		return;
 	}
